/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998 Benjamin Geer
 * Email: beroul@yahoo.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.template.instruction;

import freemarker.template.*;
import freemarker.template.compiler.*;

/**
 * A superclass for instructions that have a body and a single end instruction,
 * and that can produce output.
 */
public abstract class GenericStartInstruction extends StartInstruction {
	protected TemplateProcessor body;

	public void setBody(TemplateProcessor body) {
		this.body = body;
	}

	/**
	 * @return a string describing this <tt>GenericStartInstruction</tt>.
	 */
	public abstract String getTypeName();

	public void callBuilder(TemplateBuilder builder,
		RuntimeStructuralElement element) throws TemplateException {
		builder.buildStatement(this, element);
	}

	/**
	 * @return true if the <tt>EndInstruction</tt> is the right kind
	 * for this <tt>GenericStartInstruction</tt>.
	 */
	public abstract boolean testEndInstruction(Instruction endInstruction);
}
